June 1, 2017, 14:22 (GMT) |
Depsgraph: Cleanup, use DEG_NODE_CLASS prefix for node classes |
June 1, 2017, 14:22 (GMT) |
Depsgraph: Cleanup, use DEG_NODE_TYPE prefix for depsgraph node types |
June 1, 2017, 14:22 (GMT) |
Depsgraph: Remove unused argument from time source query |
June 1, 2017, 14:22 (GMT) |
Depsgraph: Remove subgraph nodes Those were never finished nor used. Again, starting from clean state before we go into more complicated details. |
June 1, 2017, 14:22 (GMT) |
Depsgraph: Remove dead code Was never used or worked on in ages, if any of this code is needed in the future it'll need to be redone anyway. |
June 1, 2017, 14:22 (GMT) |
Depsgraph: Remove dead code from add_time_source() This was never finished or done or used, no reason to keep it. Better to simplify things before adding complexity of overrides and copy-on-write. |
June 1, 2017, 14:22 (GMT) |
Depsgraph: Cleanup, get rid of relation type It was never actually used apart from being stored at a construciton time. This caused some redundancy and ncertanty about which relation type to use during construciton (often existing types were not close enough to particular use case). |
June 1, 2017, 13:54 (GMT) |
Cleanup: use row() sub-layout to expand enum properties horizontaly |
Revision 2ee74e9 by Antonio Vazquez (experimental_gp_weight, greasepencil-experimental, greasepencil-object, greasepencil-refactor, soc-2019-npr, temp-gpencil-eval, temp-greasepencil-object-stacksplit, temp-greasepencil-vfx) June 1, 2017, 13:46 (GMT) |
Fix error for ghost icon in palette THe ghost icon was not working with new draw manager because the check was not migrated. |
June 1, 2017, 11:23 (GMT) |
GPUCodegen: fix missing ViewMatrix in new shading. |
June 1, 2017, 10:45 (GMT) |
Fix blenderplayer build (ED_object_facemap*) |
June 1, 2017, 10:43 (GMT) |
Merge remote-tracking branch 'origin/blender2.8' into custom-manipulators |
Revision a293d02 by Martin Felke (fracture_modifier, fracture_modifier-master, temp-fracture-modifier-2.8) June 1, 2017, 10:42 (GMT) |
new "Handle" option for convert to keyframes, if set calculates handles to be auto or vector(adaptive), but can be slower |
June 1, 2017, 10:33 (GMT) |
Gawain: Optimize shader uniform access Before this change Gawain was doing list lookup twice, doing string comparison of every and each input which is not efficient and not friendly for CPUs with small cache size. Now we store hash of input name together with actual name and compare hashes first. Additionally, we do everything in a single pass which is much better from cache coherency point of view. This brings Eevee cache population time from 80ms to 60ms on my desktop and from 800ms to 400ms for Clement when navigating in a file from T50027. Reviewers: merwin, dfelinto Subscribers: fclem Differential Revision: https://developer.blender.org/D2697 |
June 1, 2017, 10:18 (GMT) |
Fix T51687: GPUmat evaluation of shader tree would crash uppon unknown/unsupported socket types. Made this resilient to unknown types, for now. Supporting specific INT sockets (through implicit conversion to GPU_FLOAT ones) is considered nice TODO. |
June 1, 2017, 09:42 (GMT) |
Merge branch '28' into custom-manipulators |
June 1, 2017, 09:41 (GMT) |
Correct select-similar end value |
Revision 81786c9 by Antonio Vazquez (experimental_gp_weight, greasepencil-experimental, greasepencil-object, greasepencil-refactor, soc-2019-npr, temp-gpencil-eval, temp-greasepencil-object-stacksplit, temp-greasepencil-vfx) June 1, 2017, 09:12 (GMT) |
Cleanup comment |
June 1, 2017, 09:10 (GMT) |
Small cleanup. Cleared every unconnected changes and fixed some minor ui bugs. |
Revision c0c0483 by Antonio Vazquez (experimental_gp_weight, greasepencil-experimental, greasepencil-object, greasepencil-refactor, soc-2019-npr, temp-gpencil-eval, temp-greasepencil-object-stacksplit, temp-greasepencil-vfx) June 1, 2017, 08:42 (GMT) |
Merge branch 'blender2.8' into greasepencil-object |
|
|
|


Master Commits
MiikaHweb | 2003-2021